@@ -994,17 +994,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 					if(env=="tikztimingtable"){
 						option="ll"; // is always 2 columns
 					}else{
-						for (int k = i + 1; k < tl.length(); k++) {
-							Token elem = tl.at(k);
-							if (elem.level < tk.level)
-								break;
-							if (elem.level > tk.level)
-								continue;
-							if (elem.subtype == Token::colDef) {
-								option = line.mid(elem.start + 1, elem.length - 2); // strip {}
-								break;
-							}
-						}
+                        option = Parsing::getArg(tl.mid(i+1),Token::colDef);
 					}
 				}
                 if(option.contains("colspec")){
@@ -1041,9 +1031,9 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
             if (word.contains('@')) {
                 continue; //ignore commands containg @
             }
-			if(!tk.optionalCommandName.isEmpty()){
+            if(!tk.optionalCommandName.isEmpty() && !tk.optionalCommandName.contains("/")){
 				word=tk.optionalCommandName;
-			}
+            }
 			Token tkEnvName;
 
 			if (word == "\\begin" || word == "\\end") {
@@ -1160,13 +1150,12 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 					continue;
 				}
 				if (word == "\\multicolumn") {
-					QRegExp rxMultiColumn("\\\\multicolumn\\{(\\d+)\\}\\{.+\\}\\{.+\\}");
-					rxMultiColumn.setMinimal(true);
-					int res = rxMultiColumn.indexIn(line, tk.start);
-					if (res > -1) {
+                    static QRegularExpression rxMultiColumn("\\\\multicolumn\\{(\\d+?)\\}\\{.+?\\}\\{.+?\\}");
+                    QRegularExpressionMatch rxMultiColumnMatch = rxMultiColumn.match(line, tk.start);
+                    if (rxMultiColumnMatch.hasMatch()) {
 						// multicoulmn before &
 						bool ok;
-						int c = rxMultiColumn.cap(1).toInt(&ok);
+                        int c = rxMultiColumnMatch.captured(1).toInt(&ok);
 						if (ok) {
 							activeEnv.top().excessCol += c - 1;
 						}
